@@ -12,11 +12,11 @@
 
 import abc
 import datetime
+from unittest import mock
 import uuid
 
 from keystoneauth1 import fixture
 from keystoneauth1 import plugin
-import mock
 from oslo_utils import timeutils
 import six
 
@@ -79,7 +79,8 @@ class CommonIdentityTests(object):
 
         self.stub_auth(json=token)
 
-    @abc.abstractproperty
+    @property
+    @abc.abstractmethod
     def version(self):
         """The API version being tested."""
 
